CHANGES
=======

tip (unreleased)
----------------

0.2.2 (2010.06.10)
------------------

- don't let Python 2.5 and earlier raise HTTPError on 201 response code
- list multiple changesets in most-recent-first order

0.2.1 (2010.06.08)
------------------

- don't force the message type to TextMessage

0.2.0 (2010.06.08)
------------------

- initial working version.

